@@ -155,7 +155,7 @@ _moderne_brand_scale = [
 def colors_by_weight(weight):
     """
     Generate a list of moderne colors with the specified weight.
-    Weights are 100, 200, 300, 400, 500, 600, 700, 800
+    Weights are 100, 300, 500, 700
     """
     return [
         __moderne_color_map["digital_blue"][weight],
@@ -189,10 +189,10 @@ def generate_colors(integer):
     Pass an option int to limit the number of colors returned.
     """
     colors = (
-        colors_by_weight("main")
+        colors_by_weight(500)
         + colors_by_weight(300)
         + colors_by_weight(700)
-        + colors_by_weight(500)
+        + colors_by_weight(100)
     )
     if integer is None:
         return colors
